.. _api:

Developer Interface
===================

.. module:: async_oauthlib


OAuth 1.0
---------

.. autoclass:: OAuth1
    :members:


OAuth 1.0 Session
-----------------

.. autoclass:: OAuth1Session
    :members:


OAuth 2.0
---------

.. autoclass:: OAuth2
    :members:

.. autoclass:: TokenUpdated
    :members:


OAuth 2.0 Session
-----------------

.. autoclass:: OAuth2Session
    :members:
